==> tabular-data-expression-widget-1.3.0-20141017.185237-147.jar: org/gcube/portlets/user/td/expressionwidget/client/ExpressionWidgetEntry.java <==
package org.gcube.portlets.user.td.expressionwidget.client;



import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.core.client.EntryPoint;
import com.google.web.bindery.event.shared.EventBus;
import com.google.web.bindery.event.shared.SimpleEventBus;


/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class ExpressionWidgetEntry  implements EntryPoint  {
	protected EventBus eventBus;
	
	public void onModuleLoad() {
		EventBus eventBus= new SimpleEventBus();
		TRId trId=new TRId("154","1969");
		String columnName="zwqvvx";
		
		//Column Expression Dialog 
		//ColumnExpressionDialog expressionDialog=new ColumnExpressionDialog("1", ColumnTypeCode.ATTRIBUTE, ColumnDataType.Integer, eventBus);
		//expressionDialog.show();
		
		
		//Column Filter Dialog
		//id=2, tableId=8, tableType=Generic
		//ColumnFilterDialog columnFilterDialog=new ColumnFilterDialog(trId, columnName, eventBus);
		//columnFilterDialog.show();
		
		//Multi Column Filter Dialog
		//MultiColumnFilterDialog multiColumnFilterDialog= new MultiColumnFilterDialog(trId, eventBus);
		//multiColumnFilterDialog.show();
	
		//Replace Column By Expression Dialog
		ReplaceColumnByExpressionDialog replaceColumnByExpression= new ReplaceColumnByExpressionDialog(trId, columnName, eventBus);
		replaceColumnByExpression.show();
		
		//HelpReplaceColumnByExpressionDialog
		//HelpReplaceColumnByExpressionDialog help= new HelpReplaceColumnByExpressionDialog(eventBus);
		//help.show();
		
		Log.info("Hello!");
	}
}

==> tabular-data-expression-widget-1.5.0-3.6.0.jar: org/gcube/portlets/user/td/expressionwidget/client/ExpressionWidgetEntry.java <==
package org.gcube.portlets.user.td.expressionwidget.client;



import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.TabResourceType;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.core.client.EntryPoint;
import com.google.web.bindery.event.shared.EventBus;
import com.google.web.bindery.event.shared.SimpleEventBus;


/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class ExpressionWidgetEntry  implements EntryPoint  {
	protected EventBus eventBus;
	
	public void onModuleLoad() {
		EventBus eventBus= new SimpleEventBus();
		TRId trId=new TRId("154",TabResourceType.STANDARD, "1969");
		String columnName="zwqvvx";
		
		//Column Expression Dialog 
		//ColumnExpressionDialog expressionDialog=new ColumnExpressionDialog("1", ColumnTypeCode.ATTRIBUTE, ColumnDataType.Integer, eventBus);
		//expressionDialog.show();
		
		
		//Column Filter Dialog
		//id=2, tableId=8, tableType=Generic
		//ColumnFilterDialog columnFilterDialog=new ColumnFilterDialog(trId, columnName, eventBus);
		//columnFilterDialog.show();
		
		//Multi Column Filter Dialog
		//MultiColumnFilterDialog multiColumnFilterDialog= new MultiColumnFilterDialog(trId, eventBus);
		//multiColumnFilterDialog.show();
	
		//Replace Column By Expression Dialog
		ReplaceColumnByExpressionDialog replaceColumnByExpression= new ReplaceColumnByExpressionDialog(trId, columnName, eventBus);
		replaceColumnByExpression.show();
		
		//HelpReplaceColumnByExpressionDialog
		//HelpReplaceColumnByExpressionDialog help= new HelpReplaceColumnByExpressionDialog(eventBus);
		//help.show();
		
		Log.info("Hello!");
	}
}
